clickedButtonIndex property
Index of the action button that was tapped, or null for a body click. Doubles as the
"was it a button click?" check via notification.clickedButtonIndex != null.
Implementation
int? clickedButtonIndex;
Index of the action button that was tapped, or null for a body click. Doubles as the
"was it a button click?" check via notification.clickedButtonIndex != null.
int? clickedButtonIndex;