communication property
Chat-style sender info, present when the push was sent as a communication notification.
Implementation
FlareLaneNotificationCommunication? communication;
Chat-style sender info, present when the push was sent as a communication notification.
FlareLaneNotificationCommunication? communication;